@@ -10,7 +10,8 @@ from typing import Union
 import torch
 from torch import nn
 
-from kindle.torch_utils import Activation, autopad
+from kindle.modules.activation import Activation
+from kindle.utils.torch_utils import autopad
 
 
 class DWConv(nn.Module):
@@ -59,6 +60,6 @@ class DWConv(nn.Module):
         """Forward."""
         return self.activation(self.batch_norm(self.conv(x)))
 
-    def fusefoward(self, x: torch.Tensor) -> torch.Tensor:
+    def fuseforward(self, x: torch.Tensor) -> torch.Tensor:
         """Fuse forward."""
         return self.activation(self.conv(x))
